pub struct ProductListAttributes {
pub customer_id: u64,
pub name: String,
pub date_created: String,
pub product_list_id: u64,
pub slug: String,
pub item_count: u64,
}Expand description
Attributes for a product list resource.
Fields
customer_id: u64The identifier of the customer who owns this list.
name: StringThe display name of the product list.
date_created: StringThe date the list was created (ISO 8601 string).
product_list_id: u64The unique identifier for this product list.
slug: StringThe URL slug for this product list.
item_count: u64The number of items currently in this product list.